/* $Id: main.c 502 2003-08-26 05:50:08Z d $ */
/* David Leonard, 2001. Public domain. */

#include <stdio.h>

#include <X11/Intrinsic.h>
#include <X11/StringDefs.h>
#include <X11/Shell.h>
#include <X11/Xmu/Editres.h>

#include "Cerdisp.h"

static void Quit(Widget, XEvent *, String *, Cardinal *);

String fallback_resources[] = {
	"*width: 240",
	"*height: 320",
	"*allowShellResize: true",
	"*saveUnder: true",
	NULL
};

XrmOptionDescRec options[] = {
	{ "-version", ".cerdisp.printVersion", XrmoptionNoArg, (XtPointer)"true" },
	{ "-verbose", ".cerdisp.verbose", XrmoptionNoArg, (XtPointer)"true" },
	{ "-port", ".cerdisp.listenPort", XrmoptionSepArg },
	{ "-scale", ".cerdisp.scale", XrmoptionSepArg, (XtPointer)"1" },
	{ "-proxy", ".cerdisp.proxy", XrmoptionSepArg },
	{ "-proxyport", ".cerdisp.proxyPort", XrmoptionSepArg },
};

XtActionsRec actions[] = {
	{ "quit",	Quit }
};

XtAppContext ac;
Widget toplevel;

int
main(argc, argv)
	int argc;
	char *argv[];
{
	Display *display;
	Atom wm_delete_window;
	XWMHints wm_hints;

        toplevel = XtOpenApplication(&ac, 
                "Xcerdisp",                     /* application_class */
                options, XtNumber(options),     /* options */
                &argc, argv,
                fallback_resources,             /* fallback_resources */
                sessionShellWidgetClass,        /* widget_class */
                NULL, 0);                       /* args */

	/* Register the quit() action */
	XtAppAddActions(ac, actions, XtNumber(actions));

	/* Create an instance of the display server */
	XtCreateManagedWidget("cerdisp", cerdispWidgetClass, toplevel, 
	    NULL, 0);
	XtRealizeWidget(toplevel);

	/* Tell the window manager that we would like keyboard focus */
	display = XtDisplay(toplevel);
	wm_hints.flags = InputHint;
	wm_hints.input = True;
	XSetWMHints(display, XtWindow(toplevel), &wm_hints);

	/* Translate a window manager delete (close) request into quit() */
	wm_delete_window = XInternAtom(display, "WM_DELETE_WINDOW", False);
	XSetWMProtocols(display, XtWindow(toplevel), &wm_delete_window, 1);
	XtOverrideTranslations(toplevel, 
	    XtParseTranslationTable("<Message>WM_PROTOCOLS:quit()"));

	/* Enable editres protocol */
	XtAddEventHandler(toplevel, 0, True, _XEditResCheckMessages, NULL);

	XtAppMainLoop(ac);

	exit(0);
}

/* Quit the application */
static void
Quit(Widget w, XEvent *e, String *params, Cardinal *num_params)
{

	XtDestroyWidget(toplevel);
	XtAppSetExitFlag(ac);
}
